@@ -13,7 +13,7 @@ class DivisionAdmin(admin.ModelAdmin):
     list_display = 'id', 'name', 'level', 'path', 'types'
     list_filter = 'level',
     search_fields = 'name', 'types', 'codes'
-    autocomplete_fields = 'parent',
+    autocomplete_fields = 'parent', 'geometry'
 
     inlines = (DivisionTranslationsInlineAdmin,)
 
@@ -23,3 +23,4 @@ class DivisionTranslationAdmin(admin.ModelAdmin):
     list_display = 'id', '__str__', 'language'
     list_filter = 'language',
     search_fields = 'name', 'synonyms', 'language'
+    autocomplete_fields = 'entity',
