@@ -5,7 +5,10 @@ from pxd_tree.hierarchy import Tree, tree_indexes
 from wcd_geo_db.const import DivisionLevel
 
 from ..query import DivisionsQuerySet
-from .mixins import CodesDefinableMixin, NamedMixin, SynonymizedMixin, create_types_field
+from .mixins import (
+    CodesDefinableMixin, NamedMixin, SynonymizedMixin,
+    create_types_field, codes_indexes
+)
 from .geometry import WithGeometryMixin
 
 
@@ -19,7 +22,7 @@ class Division(Tree, NamedMixin, SynonymizedMixin, WithGeometryMixin, CodesDefin
     class Meta:
         verbose_name = pgettext_lazy('wcd_geo_db', 'Division')
         verbose_name_plural = pgettext_lazy('wcd_geo_db', 'Divisions')
-        indexes = tree_indexes()
+        indexes = tree_indexes() + codes_indexes()
 
     id = models.BigAutoField(
         primary_key=True, verbose_name=pgettext_lazy('wcd_geo_db', 'ID')
